pyglet.sprite
=============

.. automodule:: pyglet.sprite

.. autoclass:: Sprite

  .. rubric:: Methods

  .. automethod:: delete
  .. automethod:: draw
  .. automethod:: update

  .. rubric:: Events

  .. automethod:: on_animation_end

  .. rubric:: Attributes

  .. autoattribute:: batch
  .. autoattribute:: color
  .. autoattribute:: group
  .. autoattribute:: height
  .. autoattribute:: image
  .. autoattribute:: opacity
  .. autoattribute:: position
  .. autoattribute:: rotation
  .. autoattribute:: scale
  .. autoattribute:: scale_x
  .. autoattribute:: scale_y
  .. autoattribute:: visible
  .. autoattribute:: width
  .. autoattribute:: x
  .. autoattribute:: y

.. autoclass:: SpriteGroup
  :members:
  :undoc-members:
